#
#   xts: eXtensible time-series 
#
#   Copyright (C) 2008  Jeffrey A. Ryan jeff.a.ryan @ gmail.com
#
#   Contributions from Joshua M. Ulrich
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.


# dimnames will return the actual dimnames of the xts object
# dimnames<-.xts will force the rownames to always be NULL

`dimnames.xts` <-
function(x) {
  #list(NULL, colnames(unclass(x)))
  .Call("dimnames_zoo",x,PACKAGE="xts");
  #list(as.character(index(x)), colnames(unclass(x)))
}

`dimnames<-.xts` <-
function(x, value) {
  .Call("xts_set_dimnames", x, value, PACKAGE = "xts")
}
